import fetch from 'cross-fetch';

// utils from react-notion
const getTextContent = text => {
  return text.reduce((prev, current) => prev + current[0], "");
};
const defaultMapImageUrl = (image = "", block) => {
  const url = new URL(`https://www.notion.so${image.startsWith("/image") ? image : `/image/${encodeURIComponent(image)}`}`);

  if (block && !image.includes("/images/page-cover/")) {
    const table = block.value.parent_table === "space" ? "block" : block.value.parent_table;
    url.searchParams.set("table", table);
    url.searchParams.set("id", block.value.id);
    url.searchParams.set("cache", "v2");
  }

  return url.toString();
};
const defaultMapPageUrl = (pageId = "") => {
  pageId = pageId.replace(/-/g, "");
  return `/${pageId}`;
};

const blockProps = {
  blockMap: {
    type: Object,
    required: true
  },
  contentId: {
    type: String,
    required: false
  },
  fullPage: {
    type: Boolean,
    default: false
  },
  hideList: {
    type: Array,
    default: () => []
  },
  level: {
    type: Number,
    default: 0
  },
  mapImageUrl: Function,
  mapPageUrl: Function,
  pageLinkOptions: Object,
  todo: {
    type: Boolean,
    default: false
  }
};
const blockComputed = {
  passProps() {
    return {
      blockMap: this.blockMap,
      contentId: this.contentId,
      fullPage: this.fullPage,
      hideList: this.hideList,
      level: this.level,
      mapImageUrl: this.mapImageUrl,
      mapPageUrl: this.mapPageUrl,
      pageLinkOptions: this.pageLinkOptions,
      todo: this.todo
    };
  },

  block() {
    const id = this.contentId || Object.keys(this.blockMap)[0];
    return this.blockMap[id];
  },

  value() {
    var _this$block;

    return (_this$block = this.block) === null || _this$block === void 0 ? void 0 : _this$block.value;
  },

  format() {
    var _this$value;

    return (_this$value = this.value) === null || _this$value === void 0 ? void 0 : _this$value.format;
  },

  icon() {
    var _this$format;

    return ((_this$format = this.format) === null || _this$format === void 0 ? void 0 : _this$format.page_icon) || "";
  },

  properties() {
    var _this$value2;

    return (_this$value2 = this.value) === null || _this$value2 === void 0 ? void 0 : _this$value2.properties;
  },

  titles() {
    var _this$properties;

    return (_this$properties = this.properties) === null || _this$properties === void 0 ? void 0 : _this$properties.title;
  },

  type() {
    var _this$value3;

    return (_this$value3 = this.value) === null || _this$value3 === void 0 ? void 0 : _this$value3.type;
  }

};
var Blockable = {
  props: blockProps,
  computed: blockComputed,
  methods: {
    getTextContent
  }
};

//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
//
var script = {
  name: "NotionDecorator",
  props: ["content"],
  computed: {
    text() {
      return this.content[0];
    },

    decorators() {
      return this.content[1];
    },

    decoratorKey() {
      return !!this.decorators && this.decorators[0][0];
    },

    decoratorValue() {
      return !!this.decorators && this.decorators[0][1];
    },

    unappliedDecorators() {
      const clonedDecorators = [...(this.decorators || [])];
      clonedDecorators.shift(); // remove applied decorator

      return clonedDecorators;
    },

    nextContent() {
      return [this.text, ...this.unappliedDecorators];
    }

  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.decoratorKey === 'h' ? _c('span', {
    class: 'notion-' + _vm.decoratorValue
  }, [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : _vm.decoratorKey === 'c' ? _c('code', {
    staticClass: "notion-inline-code"
  }, [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : _vm.decoratorKey === 'b' ? _c('b', [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : _vm.decoratorKey === 'i' ? _c('i', [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : _vm.decoratorKey === 's' ? _c('s', [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : _vm.decoratorKey === 'a' ? _c('a', {
    staticClass: "notion-link",
    attrs: {
      "href": _vm.decoratorValue
    }
  }, [_c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  })], 1) : !_vm.decorators ? _c('span', [_vm._v(_vm._s(_vm.text))]) : _c('NotionDecorator', {
    attrs: {
      "content": _vm.nextContent
    }
  });
};

var __vue_staticRenderFns__ = [];
/* style */

const __vue_inject_styles__ = undefined;
/* scoped */

const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

//
var script$1 = {
  extends: Blockable,
  name: "NotionPageIcon",
  props: { ...blockProps,
    big: Boolean
  }
};

/* script */
const __vue_script__$1 = script$1;
/* template */

var __vue_render__$1 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.icon.includes('http') ? _c('img', {
    class: _vm.big ? 'notion-page-icon-cover' : 'notion-page-icon',
    attrs: {
      "src": _vm.mapImageUrl(_vm.icon, _vm.block),
      "alt": _vm.titles ? _vm.getTextContent(_vm.titles) : 'Icon'
    }
  }) : _vm.icon ? _c('span', {
    class: ['notion-emoji', _vm.big ? 'notion-page-icon-cover' : 'notion-page-icon'],
    attrs: {
      "role": "img",
      "aria-label": _vm.icon
    }
  }, [_vm._v("\n  " + _vm._s(_vm.icon) + "\n")]) : _vm._e();
};

var __vue_staticRenderFns__$1 = [];
/* style */

const __vue_inject_styles__$1 = undefined;
/* scoped */

const __vue_scope_id__$1 = undefined;
/* module identifier */

const __vue_module_identifier__$1 = undefined;
/* functional template */

const __vue_is_functional_template__$1 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$1 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, undefined, undefined, undefined);

//
var script$2 = {
  extends: Blockable,
  name: "NotionCallout",
  components: {
    NotionDecorator: __vue_component__,
    NotionPageIcon: __vue_component__$1
  }
};

/* script */
const __vue_script__$2 = script$2;
/* template */

var __vue_render__$2 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "notion-callout"
  }, [_c('div', [_c('NotionPageIcon', _vm._b({}, 'NotionPageIcon', _vm.passProps, false))], 1), _vm._v(" "), _c('div', {
    staticClass: "notion-callout-text"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1)]);
};

var __vue_staticRenderFns__$2 = [];
/* style */

const __vue_inject_styles__$2 = undefined;
/* scoped */

const __vue_scope_id__$2 = undefined;
/* module identifier */

const __vue_module_identifier__$2 = undefined;
/* functional template */

const __vue_is_functional_template__$2 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$2 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$2,
  staticRenderFns: __vue_staticRenderFns__$2
}, __vue_inject_styles__$2, __vue_script__$2, __vue_scope_id__$2, __vue_is_functional_template__$2, __vue_module_identifier__$2, false, undefined, undefined, undefined);

//
//
//
//
//
//
//
const baseWidth = 46;
var script$3 = {
  name: "NotionColumn",
  props: ["format"],
  computed: {
    columnWidth() {
      const columns = Number((1 / this.format.column_ratio).toFixed(0));
      const totalWidth = (columns - 1) * baseWidth;
      return `width: calc((100% - ${totalWidth}px) * ${this.format.column_ratio})`;
    },

    spacerWidth() {
      return "width: " + baseWidth;
    }

  }
};

/* script */
const __vue_script__$3 = script$3;
/* template */

var __vue_render__$3 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "notion-column",
    style: _vm.columnWidth
  }, [_vm._t("default"), _vm._v(" "), _c('div', {
    staticClass: "notion-spacer",
    style: _vm.spacerWidth
  })], 2);
};

var __vue_staticRenderFns__$3 = [];
/* style */

const __vue_inject_styles__$3 = undefined;
/* scoped */

const __vue_scope_id__$3 = undefined;
/* module identifier */

const __vue_module_identifier__$3 = undefined;
/* functional template */

const __vue_is_functional_template__$3 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$3 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$3,
  staticRenderFns: __vue_staticRenderFns__$3
}, __vue_inject_styles__$3, __vue_script__$3, __vue_scope_id__$3, __vue_is_functional_template__$3, __vue_module_identifier__$3, false, undefined, undefined, undefined);

//
var script$4 = {
  extends: Blockable,
  name: "PageHeader",
  components: {
    Decorator: __vue_component__
  }
};

/* script */
const __vue_script__$4 = script$4;
/* template */

var __vue_render__$4 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm._m(0);
};

var __vue_staticRenderFns__$4 = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('header', {
    staticClass: "notion-page-header"
  }, [_c('div', {
    staticClass: "notion-nav-breadcrumbs"
  })]);
}];
/* style */

const __vue_inject_styles__$4 = undefined;
/* scoped */

const __vue_scope_id__$4 = undefined;
/* module identifier */

const __vue_module_identifier__$4 = undefined;
/* functional template */

const __vue_is_functional_template__$4 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$4 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$4,
  staticRenderFns: __vue_staticRenderFns__$4
}, __vue_inject_styles__$4, __vue_script__$4, __vue_scope_id__$4, __vue_is_functional_template__$4, __vue_module_identifier__$4, false, undefined, undefined, undefined);

//
var script$5 = {
  extends: Blockable,
  name: "NotionPage",
  components: {
    NotionDecorator: __vue_component__,
    NotionPageHeader: __vue_component__$4,
    NotionPageIcon: __vue_component__$1
  },
  computed: { ...blockComputed,

    coverStyle() {
      if (!this.format) return "";
      const coverPosition = (1 - (this.format.page_cover_position || 0.5)) * 100;
      return {
        objectPosition: `center ${coverPosition}%`
      };
    },

    hasPageLinkOptions() {
      var _this$pageLinkOptions, _this$pageLinkOptions2;

      return ((_this$pageLinkOptions = this.pageLinkOptions) === null || _this$pageLinkOptions === void 0 ? void 0 : _this$pageLinkOptions.component) && ((_this$pageLinkOptions2 = this.pageLinkOptions) === null || _this$pageLinkOptions2 === void 0 ? void 0 : _this$pageLinkOptions2.href);
    },

    pageLinkProps() {
      return {
        [this.pageLinkOptions.href]: this.mapPageUrl(this.value.id)
      };
    }

  }
};

/* script */
const __vue_script__$5 = script$5;
/* template */

var __vue_render__$5 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.level === 0 ? _c('div', {
    staticClass: "notion"
  }, [_c('img', {
    staticClass: "notion-page-cover",
    style: _vm.coverStyle,
    attrs: {
      "alt": _vm.getTextContent(_vm.titles),
      "src": _vm.format && _vm.mapImageUrl(_vm.format.page_cover, _vm.block)
    }
  }), _vm._v(" "), _c('main', {
    staticClass: "notion-page"
  }, [_c('NotionPageIcon', _vm._b({
    attrs: {
      "big": ""
    }
  }, 'NotionPageIcon', _vm.passProps, false)), _vm._v(" "), _c('div', {
    staticClass: "notion-title"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1), _vm._v(" "), _vm._t("default")], 2)]) : _vm.hasPageLinkOptions ? _c(_vm.pageLinkOptions.component, _vm._b({
    tag: "component",
    staticClass: "notion-page-link"
  }, 'component', _vm.pageLinkProps, false), [_c('div', {
    staticClass: "notion-page-icon"
  }, [_c('NotionPageIcon', _vm._b({}, 'NotionPageIcon', _vm.passProps, false))], 1), _vm._v(" "), _c('div', {
    staticClass: "notion-page-text"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1)]) : _c('a', {
    staticClass: "notion-page-link",
    attrs: {
      "href": _vm.mapPageUrl(_vm.value.id)
    }
  }, [_c('div', {
    staticClass: "notion-page-icon"
  }, [_c('NotionPageIcon', _vm._b({}, 'NotionPageIcon', _vm.passProps, false))], 1), _vm._v(" "), _c('div', {
    staticClass: "notion-page-text"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1)]);
};

var __vue_staticRenderFns__$5 = [];
/* style */

const __vue_inject_styles__$5 = undefined;
/* scoped */

const __vue_scope_id__$5 = undefined;
/* module identifier */

const __vue_module_identifier__$5 = undefined;
/* functional template */

const __vue_is_functional_template__$5 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$5 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$5,
  staticRenderFns: __vue_staticRenderFns__$5
}, __vue_inject_styles__$5, __vue_script__$5, __vue_scope_id__$5, __vue_is_functional_template__$5, __vue_module_identifier__$5, false, undefined, undefined, undefined);

//
var script$6 = {
  extends: Blockable,
  name: "NotionHeader",
  components: {
    NotionDecorator: __vue_component__
  }
};

/* script */
const __vue_script__$6 = script$6;
/* template */

var __vue_render__$6 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', [_vm.type === 'header' ? _c('h1', {
    staticClass: "notion-h1"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1) : _vm._e(), _vm._v(" "), _vm.type === 'sub_header' ? _c('h2', {
    staticClass: "notion-h2"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1) : _vm._e(), _vm._v(" "), _vm.type === 'sub_sub_header' ? _c('h3', {
    staticClass: "notion-h3"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1) : _vm._e()]);
};

var __vue_staticRenderFns__$6 = [];
/* style */

const __vue_inject_styles__$6 = undefined;
/* scoped */

const __vue_scope_id__$6 = undefined;
/* module identifier */

const __vue_module_identifier__$6 = undefined;
/* functional template */

const __vue_is_functional_template__$6 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$6 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$6,
  staticRenderFns: __vue_staticRenderFns__$6
}, __vue_inject_styles__$6, __vue_script__$6, __vue_scope_id__$6, __vue_is_functional_template__$6, __vue_module_identifier__$6, false, undefined, undefined, undefined);

//
var script$7 = {
  extends: Blockable,
  name: "NotionText",
  components: {
    NotionDecorator: __vue_component__
  }
};

/* script */
const __vue_script__$7 = script$7;
/* template */

var __vue_render__$7 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.properties ? _c('p', {
    staticClass: "notion-text"
  }, _vm._l(_vm.titles, function (t, i) {
    return _c('NotionDecorator', {
      key: i,
      attrs: {
        "content": t
      }
    });
  }), 1) : _c('div', {
    staticClass: "notion-blank"
  }, [_vm._v(" ")]);
};

var __vue_staticRenderFns__$7 = [];
/* style */

const __vue_inject_styles__$7 = undefined;
/* scoped */

const __vue_scope_id__$7 = undefined;
/* module identifier */

const __vue_module_identifier__$7 = undefined;
/* functional template */

const __vue_is_functional_template__$7 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$7 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$7,
  staticRenderFns: __vue_staticRenderFns__$7
}, __vue_inject_styles__$7, __vue_script__$7, __vue_scope_id__$7, __vue_is_functional_template__$7, __vue_module_identifier__$7, false, undefined, undefined, undefined);

//
var script$8 = {
  extends: Blockable,
  name: "NotionBlock",
  components: {
    NotionCallout: __vue_component__$2,
    NotionColumn: __vue_component__$3,
    NotionPage: __vue_component__$5,
    NotionHeader: __vue_component__$6,
    NotionText: __vue_component__$7
  },
  computed: { ...blockComputed,

    visible() {
      return !this.hideList.includes(this.type);
    }

  }
};

/* script */
const __vue_script__$8 = script$8;
/* template */

var __vue_render__$8 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.type === 'page' && _vm.visible ? _c('div', [_c('NotionPage', _vm._b({}, 'NotionPage', _vm.passProps, false), [_vm._t("default")], 2)], 1) : ['header', 'sub_header', 'sub_sub_header'].includes(_vm.type) && _vm.visible ? _c('NotionHeader', _vm._b({}, 'NotionHeader', _vm.passProps, false)) : _vm.type === 'text' && _vm.visible ? _c('NotionText', _vm._b({}, 'NotionText', _vm.passProps, false)) : _vm.type === 'callout' && _vm.visible ? _c('NotionCallout', _vm._b({}, 'NotionCallout', _vm.passProps, false)) : _vm.type === 'column_list' && _vm.visible ? _c('div', {
    staticClass: "notion-row"
  }, [_vm._t("default")], 2) : _vm.type === 'column' && _vm.visible ? _c('NotionColumn', {
    attrs: {
      "format": _vm.format
    }
  }, [_vm._t("default")], 2) : _vm.todo && _vm.visible ? _c('div', [_vm._v("todo: " + _vm._s(_vm.type)), _vm._t("default")], 2) : _vm.visible ? _c('div', [_vm._t("default")], 2) : _vm._e();
};

var __vue_staticRenderFns__$8 = [];
/* style */

const __vue_inject_styles__$8 = undefined;
/* scoped */

const __vue_scope_id__$8 = undefined;
/* module identifier */

const __vue_module_identifier__$8 = undefined;
/* functional template */

const __vue_is_functional_template__$8 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$8 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$8,
  staticRenderFns: __vue_staticRenderFns__$8
}, __vue_inject_styles__$8, __vue_script__$8, __vue_scope_id__$8, __vue_is_functional_template__$8, __vue_module_identifier__$8, false, undefined, undefined, undefined);

//
var script$9 = {
  extends: Blockable,
  name: "NotionRenderer",
  components: {
    NotionBlock: __vue_component__$8
  },
  props: {
    blockMap: [Object],
    contentId: String,
    fullPage: {
      type: Boolean,
      default: false
    },
    hideList: {
      type: Array,
      default: () => []
    },
    level: {
      type: Number,
      default: 0
    },
    mapImageUrl: {
      type: Function,
      default: defaultMapImageUrl
    },
    mapPageUrl: {
      type: Function,
      default: defaultMapPageUrl
    },
    pageLinkOptions: Object,
    todo: {
      type: Boolean,
      default: false
    }
  }
};

/* script */
const __vue_script__$9 = script$9;
/* template */

var __vue_render__$9 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.blockMap && _vm.value ? _c('NotionBlock', _vm._b({}, 'NotionBlock', _vm.passProps, false), _vm._l(_vm.value.content, function (contentId) {
    return _c('NotionRenderer', _vm._b({
      key: contentId,
      attrs: {
        "level": _vm.level + 1,
        "content-id": contentId
      }
    }, 'NotionRenderer', _vm.passProps, false));
  }), 1) : _vm._e();
};

var __vue_staticRenderFns__$9 = [];
/* style */

const __vue_inject_styles__$9 = undefined;
/* scoped */

const __vue_scope_id__$9 = undefined;
/* module identifier */

const __vue_module_identifier__$9 = undefined;
/* functional template */

const __vue_is_functional_template__$9 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$9 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$9,
  staticRenderFns: __vue_staticRenderFns__$9
}, __vue_inject_styles__$9, __vue_script__$9, __vue_scope_id__$9, __vue_is_functional_template__$9, __vue_module_identifier__$9, false, undefined, undefined, undefined);

/* eslint-disable import/prefer-default-export */

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  NotionRenderer: __vue_component__$9
});

const getPageTable = async (pageId, apiUrl = "https://notion-api.splitbee.io/v1") => await fetch(`${apiUrl}/table/${pageId}`).then(res => res.json());

const getPageBlocks = async (pageId, apiUrl = "https://notion-api.splitbee.io/v1") => await fetch(`${apiUrl}/page/${pageId}`).then(res => res.json());

// Import vue components

const install = function installVueNotion(Vue) {
  if (install.installed) return;
  install.installed = true;
  Object.entries(components).forEach(([componentName, component]) => {
    Vue.component(componentName, component);
  });
}; // Create module definition for Vue.use()


const plugin = {
  install
}; // To auto-install on non-es builds, when vue is found
 // todo: remove .esm from default packaging for cleaner imports

export default plugin;
export { __vue_component__$9 as NotionRenderer, getPageBlocks, getPageTable };
